@@ -1,7 +1,4 @@
 
-use Data::Dumper ;
-my $complicated_value = Dumper([{1 => [], 2 => {hi => there}}]) ;
-
 sub OneMillion
 {
 return(1_000_000) ;
@@ -18,6 +15,5 @@ A3 => Formula('$ss->Sum("A1:A2")'),
 B1 => 3,
 
 c2 => "hi there",
-c3 => $complicated_value,
 
 D1 => OneMillion()
\ No newline at end of file
